@@ -60,11 +60,6 @@ def adonis_sampler(base_url, qubit_mapping):
     return IQMSampler(base_url, Adonis(), qubit_mapping=qubit_mapping)
 
 
-@pytest.fixture()
-def adonis_sampler_without_settings(base_url):
-    return IQMSampler(base_url, Adonis())
-
-
 @pytest.mark.usefixtures('unstub')
 def test_run_sweep_executes_circuit(adonis_sampler, circuit, iqm_metadata):
     client = mock(IQMClient)
@@ -72,7 +67,6 @@ def test_run_sweep_executes_circuit(adonis_sampler, circuit, iqm_metadata):
     run_result = RunResult(status=Status.READY, measurements=[{'some stuff': [[0], [1]]}], metadata=iqm_metadata)
     when(client).submit_circuits(ANY,
                                  qubit_mapping=ANY,
-                                 settings=ANY,
                                  calibration_set_id=ANY,
                                  shots=ANY).thenReturn(run_id)
     when(client).wait_for_results(run_id).thenReturn(run_result)
@@ -94,33 +88,29 @@ def test_run_sweep_with_bad_qubit_mapping(base_url, circuit):
 
 
 @pytest.mark.usefixtures('unstub')
-def test_run_sweep_executes_circuit_without_settings(adonis_sampler_without_settings,
-                                                     circuit_with_physical_names,
-                                                     iqm_metadata):
+def test_run_sweep_executes_circuit_with_physical_names(adonis_sampler, circuit_with_physical_names, iqm_metadata):
     client = mock(IQMClient)
     run_id = uuid.uuid4()
     run_result = RunResult(status=Status.READY, measurements=[{'some stuff': [[0], [1]]}], metadata=iqm_metadata)
     when(client).submit_circuits(ANY,
                                  qubit_mapping=ANY,
-                                 settings=None,
                                  calibration_set_id=ANY,
                                  shots=ANY).thenReturn(run_id)
     when(client).wait_for_results(run_id).thenReturn(run_result)
 
-    adonis_sampler_without_settings._client = client
-    results = adonis_sampler_without_settings.run_sweep(circuit_with_physical_names, None, repetitions=2)
+    adonis_sampler._client = client
+    results = adonis_sampler.run_sweep(circuit_with_physical_names, None, repetitions=2)
     assert isinstance(results[0], cirq.Result)
 
 
 @pytest.mark.usefixtures('unstub')
-def test_run_sweep_with_parameter_sweep(adonis_sampler_without_settings, iqm_metadata):
+def test_run_sweep_with_parameter_sweep(adonis_sampler, iqm_metadata):
     client = mock(IQMClient)
     run_id = uuid.uuid4()
     run_result = RunResult(
         status=Status.READY, measurements=[{'some stuff': [[0]]}, {'some stuff': [[1]]}], metadata=iqm_metadata)
     when(client).submit_circuits(ANY,
                                  qubit_mapping=ANY,
-                                 settings=ANY,
                                  calibration_set_id=ANY,
                                  shots=ANY).thenReturn(run_id)
     when(client).wait_for_results(run_id).thenReturn(run_result)
@@ -131,9 +121,9 @@ def test_run_sweep_with_parameter_sweep(adonis_sampler_without_settings, iqm_met
     sweep_length = 2
     param_sweep = cirq.Linspace('t', start=0, stop=1, length=sweep_length)
 
-    adonis_sampler_without_settings._client = client
+    adonis_sampler._client = client
 
-    results = adonis_sampler_without_settings.run_sweep(circuit_sweep, param_sweep, repetitions=123)
+    results = adonis_sampler.run_sweep(circuit_sweep, param_sweep, repetitions=123)
     assert len(results) == sweep_length
     assert all(isinstance(result, cirq.Result) for result in results)
 
